@@ -2,6 +2,7 @@
 import asyncio
 from unittest.mock import AsyncMock, call
 
+from aiohttp.client import ClientSession
 import pytest
 
 from zwave_js_server.dump import dump_msgs
@@ -31,18 +32,33 @@ def event_fixture():
     }
 
 
+@pytest.fixture(name="no_get_log_config_client_session")
+def no_get_log_config_client_session_fixture(no_get_log_config_ws_client):
+    """Mock an aiohttp client session without calling get_log_config."""
+    no_get_log_config_client_session = AsyncMock(spec_set=ClientSession)
+    no_get_log_config_client_session.ws_connect.side_effect = AsyncMock(
+        return_value=no_get_log_config_ws_client
+    )
+    return no_get_log_config_client_session
+
+
 async def test_dump(
-    client_session, result, url, version_data, set_api_schema_data, ws_client
+    no_get_log_config_client_session,
+    result,
+    url,
+    version_data,
+    set_api_schema_data,
+    no_get_log_config_ws_client,
 ):
     """Test the dump function."""
-    messages = await dump_msgs(url, client_session)
+    messages = await dump_msgs(url, no_get_log_config_client_session)
 
-    assert ws_client.receive_json.call_count == 3
-    assert ws_client.send_json.call_count == 2
-    assert ws_client.send_json.call_args == call(
+    assert no_get_log_config_ws_client.receive_json.call_count == 3
+    assert no_get_log_config_ws_client.send_json.call_count == 2
+    assert no_get_log_config_ws_client.send_json.call_args == call(
         {"command": "start_listening", "messageId": "listen-id"}
     )
-    assert ws_client.close.call_count == 1
+    assert no_get_log_config_ws_client.close.call_count == 1
     assert messages
     assert len(messages) == 3
     assert messages[0] == version_data
@@ -51,7 +67,13 @@ async def test_dump(
 
 
 async def test_dump_timeout(
-    client_session, result, url, event, version_data, set_api_schema_data, ws_client
+    no_get_log_config_client_session,
+    result,
+    url,
+    event,
+    version_data,
+    set_api_schema_data,
+    no_get_log_config_ws_client,
 ):
     """Test the dump function with timeout."""
     to_receive = asyncio.Queue()
@@ -61,15 +83,15 @@ async def test_dump_timeout(
     async def receive_json():
         return await to_receive.get()
 
-    ws_client.receive_json = AsyncMock(side_effect=receive_json)
-    messages = await dump_msgs(url, client_session, 0.05)
+    no_get_log_config_ws_client.receive_json = AsyncMock(side_effect=receive_json)
+    messages = await dump_msgs(url, no_get_log_config_client_session, 0.05)
 
-    assert ws_client.receive_json.call_count == 5
-    assert ws_client.send_json.call_count == 2
-    assert ws_client.send_json.call_args == call(
+    assert no_get_log_config_ws_client.receive_json.call_count == 5
+    assert no_get_log_config_ws_client.send_json.call_count == 2
+    assert no_get_log_config_ws_client.send_json.call_args == call(
         {"command": "start_listening", "messageId": "listen-id"}
     )
-    assert ws_client.close.call_count == 1
+    assert no_get_log_config_ws_client.close.call_count == 1
     assert messages
     assert len(messages) == 4
     assert messages[0] == version_data
