@@ -1,12 +1,15 @@
 """Provide a model for the Z-Wave JS node."""
-from enum import IntEnum
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, TypedDict, Union, cast
 
-from ..const import CommandClass, INTERVIEW_FAILED
-from ..event import Event, EventBase
-from ..exceptions import FailedCommand, UnparseableValue, UnwriteableValue
+from ..const import INTERVIEW_FAILED, CommandClass, NodeStatus
+from ..event import Event
+from ..exceptions import (
+    FailedCommand,
+    NotFoundError,
+    UnparseableValue,
+    UnwriteableValue,
+)
 from .command_class import CommandClassInfo, CommandClassInfoDataType
-from .device_class import DeviceClass, DeviceClassDataType
 from .device_config import DeviceConfig, DeviceConfigDataType
 from .endpoint import Endpoint, EndpointDataType
 from .firmware import (
@@ -36,27 +39,69 @@ if TYPE_CHECKING:
     from ..client import Client
 
 
-class NodeStatus(IntEnum):
-    """Enum with all Node status values.
+class NodeStatisticsDataType(TypedDict):
+    """Represent a node statistics data dict type."""
 
-    https://zwave-js.github.io/node-zwave-js/#/api/node?id=status
-    """
-
-    UNKNOWN = 0
-    ASLEEP = 1
-    AWAKE = 2
-    DEAD = 3
-    ALIVE = 4
+    commandsTX: int
+    commandsRX: int
+    commandsDroppedTX: int
+    commandsDroppedRX: int
+    timeoutResponse: int
 
 
-class NodeDataType(TypedDict, total=False):
+class NodeStatistics:
+    """Represent a node statistics update."""
+
+    def __init__(self, data: Optional[NodeStatisticsDataType] = None) -> None:
+        """Initialize node statistics."""
+        self.data = data or NodeStatisticsDataType(
+            commandsDroppedRX=0,
+            commandsDroppedTX=0,
+            commandsRX=0,
+            commandsTX=0,
+            timeoutResponse=0,
+        )
+
+    @property
+    def commands_tx(self) -> int:
+        """Return number of commands successfully sent to node."""
+        return self.data["commandsTX"]
+
+    @property
+    def commands_rx(self) -> int:
+        """
+        Return number of commands received from node.
+
+        Includes responses to sent commands.
+        """
+        return self.data["commandsRX"]
+
+    @property
+    def commands_dropped_rx(self) -> int:
+        """Return number of commands from node that were dropped by host."""
+        return self.data["commandsDroppedRX"]
+
+    @property
+    def commands_dropped_tx(self) -> int:
+        """
+        Return number of outgoing commands that were dropped.
+
+        These commands could not be sent.
+        """
+        return self.data["commandsDroppedTX"]
+
+    @property
+    def timeout_response(self) -> int:
+        """Return number of Get-type cmds where node's response didn't come in time."""
+        return self.data["timeoutResponse"]
+
+
+class NodeDataType(EndpointDataType):
     """Represent a node data dict type."""
 
-    nodeId: int  # required
     name: str
     location: str
     status: int  # 0-4  # required
-    deviceClass: DeviceClassDataType
     zwavePlusVersion: int
     zwavePlusNodeType: int
     zwavePlusRoleType: int
@@ -76,9 +121,6 @@ class NodeDataType(TypedDict, total=False):
     deviceConfig: DeviceConfigDataType
     deviceDatabaseUrl: str
     keepAwake: bool
-    index: int
-    installerIcon: int
-    userIcon: int
     ready: bool
     label: str
     endpoints: List[EndpointDataType]
@@ -90,17 +132,19 @@ class NodeDataType(TypedDict, total=False):
     interviewStage: Optional[Union[int, str]]
     commandClasses: List[CommandClassInfoDataType]
     values: List[ValueDataType]
+    statistics: NodeStatisticsDataType
 
 
-class Node(EventBase):
+class Node(Endpoint):
     """Represent a Z-Wave JS node."""
 
     def __init__(self, client: "Client", data: NodeDataType) -> None:
         """Initialize the node."""
-        super().__init__()
-        self.client = client
-        self.data = data
+        super().__init__(client, data)
+        self.data: NodeDataType = data
         self._device_config = DeviceConfig(self.data.get("deviceConfig", {}))
+        self._statistics = NodeStatistics(self.data.get("statistics"))
+        self._firmware_update_progress: Optional[FirmwareUpdateProgress] = None
         self.values: Dict[str, Union[Value, ConfigurationValue]] = {}
         for val in data["values"]:
             value_id = _get_value_id_from_dict(self, val)
@@ -110,6 +154,19 @@ class Node(EventBase):
                 # If we can't parse the value, don't store it
                 pass
 
+        self.endpoints = {
+            endpoint["index"]: Endpoint(
+                self.client,
+                endpoint,
+                {
+                    value_id: value
+                    for value_id, value in self.values.items()
+                    if self.index == value.endpoint
+                },
+            )
+            for endpoint in self.data["endpoints"]
+        }
+
     def __repr__(self) -> str:
         """Return the representation."""
         return f"{type(self).__name__}(node_id={self.node_id})"
@@ -126,26 +183,6 @@ class Node(EventBase):
             self.client.driver == other.client.driver and self.node_id == other.node_id
         )
 
-    @property
-    def node_id(self) -> int:
-        """Return the node_id."""
-        return self.data["nodeId"]
-
-    @property
-    def index(self) -> Optional[int]:
-        """Return the index."""
-        return self.data.get("index")
-
-    @property
-    def installer_icon(self) -> Optional[int]:
-        """Return the installer_icon."""
-        return self.data.get("installerIcon")
-
-    @property
-    def user_icon(self) -> Optional[int]:
-        """Return the user_icon."""
-        return self.data.get("userIcon")
-
     @property
     def status(self) -> NodeStatus:
         """Return the status."""
@@ -156,11 +193,6 @@ class Node(EventBase):
         """Return the ready."""
         return self.data.get("ready")
 
-    @property
-    def device_class(self) -> DeviceClass:
-        """Return the device_class."""
-        return DeviceClass(self.data["deviceClass"])
-
     @property
     def is_listening(self) -> Optional[bool]:
         """Return the is_listening."""
@@ -266,11 +298,6 @@ class Node(EventBase):
         """Return the device database URL."""
         return self.data.get("deviceDatabaseUrl")
 
-    @property
-    def endpoints(self) -> List[Endpoint]:
-        """Return the endpoints."""
-        return [Endpoint(endpoint) for endpoint in self.data["endpoints"]]
-
     @property
     def endpoint_count_is_dynamic(self) -> Optional[bool]:
         """Return the endpoint_count_is_dynamic."""
@@ -311,6 +338,16 @@ class Node(EventBase):
         """Return all CommandClasses supported on this node."""
         return [CommandClassInfo(cc) for cc in self.data["commandClasses"]]
 
+    @property
+    def statistics(self) -> NodeStatistics:
+        """Return statistics property."""
+        return self._statistics
+
+    @property
+    def firmware_update_progress(self) -> Optional[FirmwareUpdateProgress]:
+        """Return firmware update progress."""
+        return self._firmware_update_progress
+
     def get_command_class_values(
         self, command_class: CommandClass, endpoint: int = None
     ) -> Dict[str, Union[ConfigurationValue, Value]]:
@@ -367,12 +404,14 @@ class Node(EventBase):
         self,
         val: Union[Value, str],
         new_value: Any,
-        options: dict = None,
+        options: Optional[dict] = None,
         wait_for_result: Optional[bool] = None,
     ) -> Optional[bool]:
         """Send setValue command to Node for given value (or value_id)."""
         # a value may be specified as value_id or the value itself
         if not isinstance(val, Value):
+            if val not in self.values:
+                raise NotFoundError(f"Value {val} not found on node {self}")
             val = self.values[val]
 
         if val.metadata.writeable is False:
@@ -383,6 +422,18 @@ class Node(EventBase):
             "value": new_value,
         }
         if options:
+            option = next(
+                (
+                    option
+                    for option in options
+                    if option not in val.metadata.value_change_options
+                ),
+                None,
+            )
+            if option is not None:
+                raise NotFoundError(
+                    f"Option {option} not found on value {val} on node {self}"
+                )
             cmd_args["options"] = options
 
         # the value object needs to be send to the server
@@ -570,12 +621,20 @@ class Node(EventBase):
 
     def handle_firmware_update_progress(self, event: Event) -> None:
         """Process a node firmware update progress event."""
-        event.data["firmware_update_progress"] = FirmwareUpdateProgress(
+        self._firmware_update_progress = event.data[
+            "firmware_update_progress"
+        ] = FirmwareUpdateProgress(
             self, cast(FirmwareUpdateProgressDataType, event.data)
         )
 
     def handle_firmware_update_finished(self, event: Event) -> None:
         """Process a node firmware update finished event."""
+        self._firmware_update_progress = None
         event.data["firmware_update_finished"] = FirmwareUpdateFinished(
             self, cast(FirmwareUpdateFinishedDataType, event.data)
         )
+
+    def handle_statistics_updated(self, event: Event) -> None:
+        """Process a statistics updated event."""
+        self._statistics.data.update(event.data["statistics"])
+        event.data["statistics_updated"] = self.statistics
